Horizontal Example
===============================================================================

:download:`horizontal.enaml <../../../examples/layout/basic/horizontal.enaml>`

.. literalinclude:: ../../../examples/layout/basic/horizontal.enaml
    :language: python

::

 $ enaml-run horizontal.enaml

.. image:: images/horizontal.png
